@@ -1,12 +1,15 @@
 import copy
+from functools import partial
+import os
+import time
+
+import astropy.units as u
+import astropy.coordinates as coord
 import corner
 import emcee
-from functools import partial
 from matplotlib import pyplot as plt
 import numpy as np
-import os
 from scipy import optimize
-import time
 
 from .atmosphere_model_reader import AtmosphereModelReader
 from .reddening import reddening_vector_filter, reddening_vector_interpolated
@@ -37,9 +40,103 @@ class WDfitter(AtmosphereModelReader):
         self.sampler = {"H": [], "He": []}
         self.samples = {"H": [], "He": []}
         self.extinction_convolved = None
+        self.set_extinction_mode()
         # Note this is the extinction Rv, not radial velocity RV.
         self.rv = None
 
+    def set_extinction_mode(self, mode="total", z_min=100.0, z_max=250.0):
+
+        if mode == "total":
+
+            self.extinction_mode = mode
+            self.z_min = None
+            self.z_max = None
+
+        elif mode == "linear":
+
+            if z_min < 0:
+
+                raise ValueError(
+                    "z_min has to be non-negative. {} is provided.".format(
+                        z_min
+                    )
+                )
+
+            if z_max < z_min:
+
+                raise ValueError(
+                    "z_max ({}) has to be larger than z_min ({}).".format(
+                        z_max, z_min
+                    )
+                )
+
+            self.extinction_mode = mode
+            self.z_min = z_min
+            self.z_max = z_max
+
+        else:
+
+            raise ValueError("Unknown extinction mode: {}.".format(mode))
+
+    def _get_extinction_fraction(self, distance, ra, dec):
+        """
+        The linear mode follows the scheme on page 5 of Harris et al. (2006)
+        in https://arxiv.org/pdf/astro-ph/0510820.pdf.
+
+        The conversion from distance, ra and dec to z is powered by AstroPy
+        coordinate transformation.
+
+        Parameters
+        ----------
+        distance : float
+            Distance to the target (in unit of pc)
+        ra : float
+            Right Ascension in unit of degree.
+        dec : float
+            Declination in unit of degree.
+
+        Returns
+        -------
+        The fraction (of extinction) should be used, in the range of
+        [0.0, 1.0].
+
+        """
+
+        c = coord.SkyCoord(
+            ra=ra * u.degree,
+            dec=dec * u.degree,
+            distance=distance * u.pc,
+            frame="icrs",
+        )
+        c_gal_cen = c.transform_to(coord.Galactocentric)
+
+        if (self.z_min is None) or (self.z_max is None):
+
+            raise ValueError(
+                "z_min and z_max cannot be None, please initialise with "
+                "set_extinction_mode()"
+            )
+
+        else:
+
+            # Get the distance from the Galactic mid-plane
+            z = getattr(c_gal_cen, "z").value
+
+            # if z is lower than the lower limit, assume no extinction
+            if z < self.z_min:
+
+                return 0.0
+
+            # if z is higher than the upper limit, assume total extinction
+            elif z > self.z_max:
+
+                return 1.0
+
+            # Otherwise, apply a linear approximation of the extinction
+            else:
+
+                return (z - self.z_min) / (self.z_max - self.z_min)
+
     def _interp_am(
         self,
         dependent,
@@ -154,6 +251,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -177,6 +276,8 @@ class WDfitter(AtmosphereModelReader):
                 interpolator_filter,
                 Rv,
                 ebv,
+                ra,
+                dec,
                 True,
             )
 
@@ -200,6 +301,8 @@ class WDfitter(AtmosphereModelReader):
                     logg_pos,
                     Rv,
                     ebv,
+                    ra,
+                    dec,
                     True,
                 )
 
@@ -216,6 +319,8 @@ class WDfitter(AtmosphereModelReader):
                     logg,
                     Rv,
                     ebv,
+                    ra,
+                    dec,
                     True,
                 )
 
@@ -237,6 +342,8 @@ class WDfitter(AtmosphereModelReader):
         interpolator_filter,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -250,7 +357,21 @@ class WDfitter(AtmosphereModelReader):
 
             mag.append(interp(x))
 
-        Av = np.array([i(Rv) for i in self.rv]).reshape(-1) * ebv
+        if self.extinction_mode == "total":
+
+            self.extinction_fraction = 1.0
+
+        else:
+
+            self.extinction_fraction = self._get_extinction_fraction(
+                distance, ra, dec
+            )
+
+        Av = (
+            np.array([i(Rv) for i in self.rv]).reshape(-1)
+            * ebv
+            * self.extinction_fraction
+        )
         mag = np.asarray(mag).reshape(-1)
         err2 = (
             errors**2.0 + (distance_err / distance * 2.17147241) ** 2.0
@@ -297,6 +418,8 @@ class WDfitter(AtmosphereModelReader):
         logg_pos,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -322,8 +445,22 @@ class WDfitter(AtmosphereModelReader):
 
                 return np.ones_like(obs) * np.inf
 
+        if self.extinction_mode == "total":
+
+            self.extinction_fraction = 1.0
+
+        else:
+
+            self.extinction_fraction = self._get_extinction_fraction(
+                distance, ra, dec
+            )
+
         logg = x[logg_pos]
-        Av = np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1) * ebv
+        Av = (
+            np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1)
+            * ebv
+            * self.extinction_fraction
+        )
         mag = np.asarray(mag).reshape(-1)
         err2 = (
             errors**2.0 + (distance_err / distance * 2.17147241) ** 2.0
@@ -370,6 +507,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -383,8 +522,22 @@ class WDfitter(AtmosphereModelReader):
 
             mag.append(interp(x))
 
+        if self.extinction_mode == "total":
+
+            self.extinction_fraction = 1.0
+
+        else:
+
+            self.extinction_fraction = self._get_extinction_fraction(
+                distance, ra, dec
+            )
+
         teff = float(interpolator_teff(x))
-        Av = np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1) * ebv
+        Av = (
+            np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1)
+            * ebv
+            * self.extinction_fraction
+        )
         mag = np.asarray(mag).reshape(-1)
         err2 = (
             errors**2.0 + (distance_err / distance * 2.17147241) ** 2.0
@@ -525,7 +678,16 @@ class WDfitter(AtmosphereModelReader):
                 return np.ones_like(obs) * np.inf
 
     def _diff2_distance_red_interpolated(
-        self, x, obs, errors, interpolator_filter, Rv, ebv, return_err
+        self,
+        x,
+        obs,
+        errors,
+        interpolator_filter,
+        Rv,
+        ebv,
+        ra,
+        dec,
+        return_err,
     ):
         """
         Internal method for computing the ch2-squared value in cases when
@@ -549,7 +711,21 @@ class WDfitter(AtmosphereModelReader):
 
             mag.append(interp(x[:2]))
 
-        Av = np.array([i(Rv) for i in self.rv]).reshape(-1) * ebv
+        if self.extinction_mode == "total":
+
+            self.extinction_fraction = 1.0
+
+        else:
+
+            self.extinction_fraction = self._get_extinction_fraction(
+                x[-1], ra, dec
+            )
+
+        Av = (
+            np.array([i(Rv) for i in self.rv]).reshape(-1)
+            * ebv
+            * self.extinction_fraction
+        )
         mag = np.asarray(mag).reshape(-1)
         err2 = errors**2.0
 
@@ -591,6 +767,8 @@ class WDfitter(AtmosphereModelReader):
         logg_pos,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -615,9 +793,23 @@ class WDfitter(AtmosphereModelReader):
 
             mag.append(interp(x[:2]))
 
+        if self.extinction_mode == "total":
+
+            self.extinction_fraction = 1.0
+
+        else:
+
+            self.extinction_fraction = self._get_extinction_fraction(
+                x[-1], ra, dec
+            )
+
         teff = float(interpolator_teff(x[:2]))
         logg = x[logg_pos]
-        Av = np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1) * ebv
+        Av = (
+            np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1)
+            * ebv
+            * self.extinction_fraction
+        )
         mag = np.asarray(mag).reshape(-1)
         err2 = errors**2.0
 
@@ -650,7 +842,16 @@ class WDfitter(AtmosphereModelReader):
                 return np.ones_like(obs) * np.inf
 
     def _diff2_distance_red_interpolated_fixed_logg(
-        self, x, obs, errors, interpolator_filter, Rv, ebv, return_err
+        self,
+        x,
+        obs,
+        errors,
+        interpolator_filter,
+        Rv,
+        ebv,
+        ra,
+        dec,
+        return_err,
     ):
         """
         Internal method for computing the ch2-squared value in cases when
@@ -674,7 +875,21 @@ class WDfitter(AtmosphereModelReader):
 
             mag.append(interp(x[0]))
 
-        Av = np.array([i(Rv) for i in self.rv]).reshape(-1) * ebv
+        if self.extinction_mode == "total":
+
+            self.extinction_fraction = 1.0
+
+        else:
+
+            self.extinction_fraction = self._get_extinction_fraction(
+                x[-1], ra, dec
+            )
+
+        Av = (
+            np.array([i(Rv) for i in self.rv]).reshape(-1)
+            * ebv
+            * self.extinction_fraction
+        )
         mag = np.asarray(mag).reshape(-1)
         err2 = errors**2.0
 
@@ -716,6 +931,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -740,8 +957,22 @@ class WDfitter(AtmosphereModelReader):
 
             mag.append(interp(x[0]))
 
+        if self.extinction_mode == "total":
+
+            self.extinction_fraction = 1.0
+
+        else:
+
+            self.extinction_fraction = self._get_extinction_fraction(
+                x[-1], ra, dec
+            )
+
         teff = float(interpolator_teff(x[0]))
-        Av = np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1) * ebv
+        Av = (
+            np.array([i([logg, teff, Rv]) for i in self.rv]).reshape(-1)
+            * ebv
+            * self.extinction_fraction
+        )
         mag = np.asarray(mag).reshape(-1)
         err2 = errors**2.0
 
@@ -783,6 +1014,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -796,13 +1029,29 @@ class WDfitter(AtmosphereModelReader):
             if logg is None:
 
                 diff2, err2 = self._diff2_distance_red_interpolated(
-                    x, obs, errors, interpolator_filter, Rv, ebv, True
+                    x,
+                    obs,
+                    errors,
+                    interpolator_filter,
+                    Rv,
+                    ebv,
+                    ra,
+                    dec,
+                    True,
                 )
 
             else:
 
                 diff2, err2 = self._diff2_distance_red_interpolated_fixed_logg(
-                    x, obs, errors, interpolator_filter, Rv, ebv, True
+                    x,
+                    obs,
+                    errors,
+                    interpolator_filter,
+                    Rv,
+                    ebv,
+                    ra,
+                    dec,
+                    True,
                 )
 
         else:
@@ -823,6 +1072,8 @@ class WDfitter(AtmosphereModelReader):
                     logg_pos,
                     Rv,
                     ebv,
+                    ra,
+                    dec,
                     True,
                 )
 
@@ -837,6 +1088,8 @@ class WDfitter(AtmosphereModelReader):
                     logg,
                     Rv,
                     ebv,
+                    ra,
+                    dec,
                     True,
                 )
 
@@ -875,6 +1128,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -894,6 +1149,8 @@ class WDfitter(AtmosphereModelReader):
             logg,
             Rv,
             ebv,
+            ra,
+            dec,
             True,
         )
 
@@ -944,6 +1201,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
         return_err,
     ):
         """
@@ -961,6 +1220,8 @@ class WDfitter(AtmosphereModelReader):
             logg,
             Rv,
             ebv,
+            ra,
+            dec,
             True,
         )
 
@@ -1016,6 +1277,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
     ):
         """
         Internal method for computing the log-likelihood value (for emcee).
@@ -1033,6 +1296,8 @@ class WDfitter(AtmosphereModelReader):
             logg,
             Rv,
             ebv,
+            ra,
+            dec,
             True,
         )
 
@@ -1083,6 +1348,8 @@ class WDfitter(AtmosphereModelReader):
         logg,
         Rv,
         ebv,
+        ra,
+        dec,
     ):
         """
         Internal method for computing the log-likelihood value in cases when
@@ -1099,6 +1366,8 @@ class WDfitter(AtmosphereModelReader):
             logg,
             Rv,
             ebv,
+            ra,
+            dec,
             True,
         )
 
@@ -1123,6 +1392,8 @@ class WDfitter(AtmosphereModelReader):
         kind="cubic",
         Rv=0.0,
         ebv=0.0,
+        ra=None,
+        dec=None,
         independent=["Mbol", "logg"],
         initial_guess=[10.0, 8.0],
         logg=8.0,
@@ -1188,6 +1459,10 @@ class WDfitter(AtmosphereModelReader):
             The choice of Rv, only used if a numerical value is provided.
         ebv: float (Default: None)
             The magnitude of the E(B-V).
+        ra : float (Default: None)
+            Right Ascension in unit of degree.
+        dec : float (Default: None)
+            Declination in unit of degree.
         independent: list of str (Default: ['Mbol', 'logg']
             Independent variables to be interpolated in the atmosphere model,
             these are parameters to be fitted for.
@@ -1369,6 +1644,8 @@ class WDfitter(AtmosphereModelReader):
             "kind": kind,
             "Rv": Rv,
             "ebv": ebv,
+            "ra": ra,
+            "dec": dec,
             "reuse_interpolator": reuse_interpolator,
             "method": method,
             "nwalkers": nwalkers,
@@ -1446,6 +1723,8 @@ class WDfitter(AtmosphereModelReader):
                                     None,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_minimize,
@@ -1463,6 +1742,8 @@ class WDfitter(AtmosphereModelReader):
                                     logg,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_minimize,
@@ -1501,6 +1782,8 @@ class WDfitter(AtmosphereModelReader):
                                     None,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_minimize,
@@ -1520,6 +1803,8 @@ class WDfitter(AtmosphereModelReader):
                                     logg,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_minimize,
@@ -1626,6 +1911,8 @@ class WDfitter(AtmosphereModelReader):
                                     None,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_least_squares,
@@ -1644,6 +1931,8 @@ class WDfitter(AtmosphereModelReader):
                                     logg,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_least_squares,
@@ -1685,6 +1974,8 @@ class WDfitter(AtmosphereModelReader):
                                     None,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_least_squares,
@@ -1705,6 +1996,8 @@ class WDfitter(AtmosphereModelReader):
                                     logg,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                     False,
                                 ),
                                 **_kwargs_for_least_squares,
@@ -1839,6 +2132,8 @@ class WDfitter(AtmosphereModelReader):
                                     None,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                 ),
                                 **_kwargs_for_emcee,
                             )
@@ -1857,6 +2152,8 @@ class WDfitter(AtmosphereModelReader):
                                     logg,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                 ),
                                 **_kwargs_for_emcee,
                             )
@@ -1898,6 +2195,8 @@ class WDfitter(AtmosphereModelReader):
                                     None,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                 ),
                                 **_kwargs_for_emcee,
                             )
@@ -1921,6 +2220,8 @@ class WDfitter(AtmosphereModelReader):
                                     logg,
                                     Rv,
                                     ebv,
+                                    ra,
+                                    dec,
                                 ),
                                 **_kwargs_for_emcee,
                             )
@@ -1996,6 +2297,8 @@ class WDfitter(AtmosphereModelReader):
                             initial_guess=_initial_guess,
                             Rv=Rv,
                             ebv=ebv,
+                            ra=ra,
+                            dec=dec,
                             kwargs_for_minimize=kwargs,
                         )
 
@@ -2016,6 +2319,8 @@ class WDfitter(AtmosphereModelReader):
                             initial_guess=_initial_guess,
                             Rv=Rv,
                             ebv=ebv,
+                            ra=ra,
+                            dec=dec,
                             kwargs_for_minimize=kwargs,
                         )
 
@@ -2113,6 +2418,7 @@ class WDfitter(AtmosphereModelReader):
                                 dtype=np.float64,
                             ).reshape(-1)
                             * ebv
+                            * self.extinction_fraction
                         )
 
                     else:
@@ -2122,6 +2428,7 @@ class WDfitter(AtmosphereModelReader):
                                 [i(Rv) for i in self.rv], dtype=np.float64
                             ).reshape(-1)
                             * ebv
+                            * self.extinction_fraction
                         )
 
                     Av[np.isnan(Av)] = 0.0
