@@ -65,8 +65,8 @@ def test_minimize_Teff_logg():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -93,8 +93,8 @@ def test_minimize_Teff():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -123,8 +123,8 @@ def test_minimize_Teff_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -154,8 +154,8 @@ def test_minimize_Teff_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -183,8 +183,8 @@ def test_minimize_Teff_logg_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -213,8 +213,8 @@ def test_minimize_Teff_logg_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -238,8 +238,8 @@ def test_minimize_Teff_logg_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -264,8 +264,8 @@ def test_minimize_Teff_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -292,8 +292,8 @@ def test_minimize_Teff_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -321,8 +321,8 @@ def test_minimize_Teff_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -348,8 +348,8 @@ def test_minimize_Teff_logg_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -376,8 +376,8 @@ def test_minimize_Teff_logg_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -405,8 +405,8 @@ def test_lsq_Teff_logg():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -433,8 +433,8 @@ def test_lsq_Teff():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -463,8 +463,8 @@ def test_lsq_Teff_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -494,8 +494,8 @@ def test_lsq_Teff_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -523,8 +523,8 @@ def test_lsq_Teff_logg_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -553,8 +553,8 @@ def test_lsq_Teff_logg_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -578,8 +578,8 @@ def test_lsq_Teff_logg_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -605,8 +605,8 @@ def test_lsq_Teff_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -633,8 +633,8 @@ def test_lsq_Teff_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -662,8 +662,8 @@ def test_lsq_Teff_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -689,8 +689,8 @@ def test_lsq_Teff_logg_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -717,8 +717,8 @@ def test_lsq_Teff_logg_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -743,7 +743,7 @@ def test_emcee_Teff_logg():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 7.5],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         distance=10.0,
@@ -754,8 +754,8 @@ def test_emcee_Teff_logg():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -775,7 +775,7 @@ def test_emcee_Teff():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -787,8 +787,8 @@ def test_emcee_Teff():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -808,7 +808,7 @@ def test_emcee_Teff_reddening():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -822,8 +822,8 @@ def test_emcee_Teff_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -844,7 +844,7 @@ def test_emcee_Teff_reddening_interpolated():
         extinction_convolved=False,
         initial_guess=[13000.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -858,8 +858,8 @@ def test_emcee_Teff_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -879,7 +879,7 @@ def test_emcee_Teff_logg_reddening():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 7.5],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         distance=10.0,
@@ -892,8 +892,8 @@ def test_emcee_Teff_logg_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -914,7 +914,7 @@ def test_emcee_Teff_logg_reddening_interpolated():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 7.5],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         distance=10.0,
@@ -927,8 +927,8 @@ def test_emcee_Teff_logg_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -976,7 +976,7 @@ def test_emcee_Teff_logg_distance():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 7.5, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
     )
@@ -985,8 +985,8 @@ def test_emcee_Teff_logg_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1034,7 +1034,7 @@ def test_emcee_Teff_distance():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -1044,8 +1044,8 @@ def test_emcee_Teff_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1095,7 +1095,7 @@ def test_emcee_Teff_distance_reddening():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -1107,8 +1107,8 @@ def test_emcee_Teff_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1162,7 +1162,7 @@ def test_emcee_Teff_distance_reddening_interpolated():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -1174,8 +1174,8 @@ def test_emcee_Teff_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1225,7 +1225,7 @@ def test_emcee_Teff_logg_distance_reddening():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 7.5, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         Rv=rv,
@@ -1236,8 +1236,8 @@ def test_emcee_Teff_logg_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1291,7 +1291,7 @@ def test_emcee_Teff_logg_distance_reddening_interpolated():
         atmosphere_interpolator="CT",
         initial_guess=[13000.0, 7.5, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         Rv=rv,
@@ -1302,6 +1302,6 @@ def test_emcee_Teff_logg_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
