@@ -44,6 +44,7 @@ extinction_grizyJHK = np.array(
     [A_g, A_r, A_i, A_z, A_y, A_J, A_H, A_Ks]
 ).reshape(-1)
 
+
 # Fitting Teff: Yes
 # Fitting logg: Yes
 # Fitting distance: No
@@ -64,8 +65,8 @@ def test_minimize_Teff_logg():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -92,8 +93,8 @@ def test_minimize_Teff():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -122,8 +123,33 @@ def test_minimize_Teff_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="minimize",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0],
+        logg=7.5,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -153,8 +179,34 @@ def test_minimize_Teff_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="minimize",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0],
+        logg=7.5,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -182,8 +234,32 @@ def test_minimize_Teff_logg_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="minimize",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5],
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -212,8 +288,33 @@ def test_minimize_Teff_logg_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="minimize",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5],
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -237,8 +338,8 @@ def test_minimize_Teff_logg_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -263,8 +364,8 @@ def test_minimize_Teff_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -291,8 +392,31 @@ def test_minimize_Teff_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="minimize",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 10.0],
+        logg=7.5,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -320,8 +444,8 @@ def test_minimize_Teff_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -347,8 +471,30 @@ def test_minimize_Teff_logg_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="minimize",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5, 10.0],
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -375,8 +521,31 @@ def test_minimize_Teff_logg_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="minimize",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5, 10.0],
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -404,8 +573,8 @@ def test_lsq_Teff_logg():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -432,8 +601,8 @@ def test_lsq_Teff():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -462,8 +631,33 @@ def test_lsq_Teff_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="least_squares",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0],
+        logg=7.5,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -493,8 +687,34 @@ def test_lsq_Teff_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="least_squares",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0],
+        logg=7.5,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -522,8 +742,32 @@ def test_lsq_Teff_logg_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="least_squares",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5],
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -552,8 +796,33 @@ def test_lsq_Teff_logg_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="least_squares",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5],
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -577,8 +846,8 @@ def test_lsq_Teff_logg_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -604,8 +873,8 @@ def test_lsq_Teff_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -632,8 +901,31 @@ def test_lsq_Teff_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="least_squares",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 10.0],
+        logg=7.5,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -661,8 +953,32 @@ def test_lsq_Teff_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="least_squares",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 10.0],
+        logg=7.5,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -688,8 +1004,30 @@ def test_lsq_Teff_logg_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="least_squares",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5, 10.0],
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -716,8 +1054,31 @@ def test_lsq_Teff_logg_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="least_squares",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5, 10.0],
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -742,7 +1103,7 @@ def test_emcee_Teff_logg():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 7.5],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         distance=10.0,
@@ -753,8 +1114,8 @@ def test_emcee_Teff_logg():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -774,7 +1135,7 @@ def test_emcee_Teff():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -786,8 +1147,8 @@ def test_emcee_Teff():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -807,7 +1168,7 @@ def test_emcee_Teff_reddening():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -821,8 +1182,38 @@ def test_emcee_Teff_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="emcee",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        logg=7.5,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -843,7 +1234,7 @@ def test_emcee_Teff_reddening_interpolated():
         extinction_convolved=False,
         initial_guess=[13000.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -857,8 +1248,39 @@ def test_emcee_Teff_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff"],
+        method="emcee",
+        atmosphere_interpolator="RBF",
+        extinction_convolved=False,
+        initial_guess=[13000.0],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        logg=7.5,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -878,7 +1300,7 @@ def test_emcee_Teff_logg_reddening():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 7.5],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         distance=10.0,
@@ -891,8 +1313,37 @@ def test_emcee_Teff_logg_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="emcee",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -913,7 +1364,7 @@ def test_emcee_Teff_logg_reddening_interpolated():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 7.5],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         distance=10.0,
@@ -926,8 +1377,38 @@ def test_emcee_Teff_logg_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=["G3", "G3_BP", "G3_RP", "FUV", "NUV"],
+        mags=mags + extinction_interpolated,
+        mag_errors=[0.02, 0.02, 0.02, 0.02, 0.02],
+        independent=["Teff", "logg"],
+        method="emcee",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        distance=10.0,
+        distance_err=0.1,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -975,7 +1456,7 @@ def test_emcee_Teff_logg_distance():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 7.5, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
     )
@@ -984,8 +1465,8 @@ def test_emcee_Teff_logg_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1033,7 +1514,7 @@ def test_emcee_Teff_distance():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -1043,8 +1524,8 @@ def test_emcee_Teff_distance():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1094,7 +1575,7 @@ def test_emcee_Teff_distance_reddening():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -1106,8 +1587,66 @@ def test_emcee_Teff_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=[
+            "G3",
+            "G3_BP",
+            "G3_RP",
+            "FUV",
+            "NUV",
+            "g_ps1",
+            "r_ps1",
+            "i_ps1",
+            "z_ps1",
+            "y_ps1",
+            "J",
+            "H",
+            "Ks",
+        ],
+        mags=np.concatenate(
+            (mags + extinction, mags_grizyJHK + extinction_grizyJHK)
+        ),
+        mag_errors=[
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+        ],
+        independent=["Teff"],
+        method="emcee",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 10.0],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        logg=7.5,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1161,7 +1700,7 @@ def test_emcee_Teff_distance_reddening_interpolated():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         logg=7.5,
@@ -1173,8 +1712,70 @@ def test_emcee_Teff_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=[
+            "G3",
+            "G3_BP",
+            "G3_RP",
+            "FUV",
+            "NUV",
+            "g_ps1",
+            "r_ps1",
+            "i_ps1",
+            "z_ps1",
+            "y_ps1",
+            "J",
+            "H",
+            "Ks",
+        ],
+        mags=np.concatenate(
+            (
+                mags + extinction_interpolated,
+                mags_grizyJHK + extinction_grizyJHK_interpolated,
+            )
+        ),
+        mag_errors=[
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+        ],
+        independent=["Teff"],
+        method="emcee",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 10.0],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        logg=7.5,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1224,7 +1825,7 @@ def test_emcee_Teff_logg_distance_reddening():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 7.5, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         Rv=rv,
@@ -1235,8 +1836,65 @@ def test_emcee_Teff_logg_distance_reddening():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=[
+            "G3",
+            "G3_BP",
+            "G3_RP",
+            "FUV",
+            "NUV",
+            "g_ps1",
+            "r_ps1",
+            "i_ps1",
+            "z_ps1",
+            "y_ps1",
+            "J",
+            "H",
+            "Ks",
+        ],
+        mags=np.concatenate(
+            (mags + extinction, mags_grizyJHK + extinction_grizyJHK)
+        ),
+        mag_errors=[
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+        ],
+        independent=["Teff", "logg"],
+        method="emcee",
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5, 10.0],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
 
 
@@ -1290,7 +1948,7 @@ def test_emcee_Teff_logg_distance_reddening_interpolated():
         atmosphere_interpolator="RBF",
         initial_guess=[13000.0, 7.5, 10.0],
         refine=False,
-        nwalkers=100,
+        nwalkers=20,
         nsteps=1000,
         nburns=100,
         Rv=rv,
@@ -1301,6 +1959,67 @@ def test_emcee_Teff_logg_distance_reddening_interpolated():
     assert np.isclose(
         ftr.best_fit_params["H"]["Teff"],
         13000.0,
-        rtol=2.5e-02,
-        atol=2.5e-02,
+        rtol=1e-01,
+        atol=1e-01,
+    )
+    ftr.set_extinction_mode(mode="linear", z_min=0, z_max=1)
+    ftr.fit(
+        atmosphere="H",
+        filters=[
+            "G3",
+            "G3_BP",
+            "G3_RP",
+            "FUV",
+            "NUV",
+            "g_ps1",
+            "r_ps1",
+            "i_ps1",
+            "z_ps1",
+            "y_ps1",
+            "J",
+            "H",
+            "Ks",
+        ],
+        mags=np.concatenate(
+            (
+                mags + extinction_interpolated,
+                mags_grizyJHK + extinction_grizyJHK_interpolated,
+            )
+        ),
+        mag_errors=[
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+            0.02,
+        ],
+        independent=["Teff", "logg"],
+        method="emcee",
+        extinction_convolved=False,
+        atmosphere_interpolator="RBF",
+        initial_guess=[13000.0, 7.5, 10.0],
+        refine=False,
+        nwalkers=20,
+        nsteps=1000,
+        nburns=100,
+        Rv=rv,
+        ebv=ebv,
+        ra=192.85949646,
+        dec=27.12835323,
+    )
+    ftr.best_fit_params["H"]["Mbol"]
+    ftr.best_fit_params["H"]["Teff"]
+    assert np.isclose(
+        ftr.best_fit_params["H"]["Teff"],
+        13000.0,
+        rtol=1e-01,
+        atol=1e-01,
     )
